@@ -16,11 +16,11 @@
 
 use crate::{Arc, String, Vec};
 pub use snarkvm_algorithms::fft::DensePolynomial as Polynomial;
-use snarkvm_errors::serialization::SerializationError;
-use snarkvm_models::curves::Field;
+use snarkvm_fields::Field;
 use snarkvm_utilities::{
     bytes::{FromBytes, ToBytes},
     error as error_fn,
+    errors::SerializationError,
     serialize::*,
 };
 
